@@ -16,7 +16,7 @@ import pandas as pd
 from pymatgen import MPRester
 from tqdm import tqdm
 
-from featurebox.tools.exports import Store
+from mgetool.exports import Store
 
 
 def data_fetcher(api_key, mp_ids, elasticity=True):
