@@ -9,6 +9,8 @@ from abc import ABCMeta, abstractmethod
 
 import numpy as np
 from pymatgen.core.composition import Composition as PMGComp
+from pymatgen.core.periodic_table import get_el_sp
+from pymatgen.util.string import formula_double_format
 
 from featurebox.featurizers.base import BaseFeaturizer
 from featurebox.featurizers.extrastats import PropertyStats
@@ -372,7 +374,10 @@ class DepartElementFeaturizer(BaseCompositionFeaturizer):
     def featurize(self, comp):
         elems_, nums_ = [], []
         if isinstance(comp, PMGComp):
-            comp = comp.to_reduced_dict
+            sym_amt = comp.get_el_amt_dict()
+            syms = sorted(sym_amt.keys(), key=lambda sym: get_el_sp(sym).X)
+            comp = {s: formula_double_format(sym_amt[s], False) for s in syms}
+
         for e, n in comp.items():
             elems_.append(e)
             nums_.append(n)
